@@ -36,7 +36,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 
 For more information, please refer to <https://unlicense.org>
 """
-import sys
+# pylint: disable=C0103  # Aligning method names to API operation IDs
 from ._util import service_request, force_default, args_to_params
 from ._service_class import ServiceClass
 from ._endpoint._mssp import _mssp_endpoints as ENDPOINTS
@@ -47,13 +47,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
        is a valid token provided by the Falcon API SDK OAuth2 class.
     """
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def getChildren(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  # Matching API
+    def getChildren(self: object, parameters: dict = None, **kwargs) -> dict:
         """Get link to child customer by child CID(s)"""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/getChildren
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "getChildren"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -64,13 +64,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def getCIDGroupMembersBy(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103
+    def getCIDGroupMembersBy(self: object, parameters: dict = None, **kwargs) -> dict:
         """Get CID Group members by CID Group IDs."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/getCIDGroupMembersBy
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "getCIDGroupMembersBy"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -80,11 +80,11 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def addCIDGroupMembers(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def addCIDGroupMembers(self: object, body: dict) -> dict:
         """Add new CID Group member."""
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/addCIDGroupMembers
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "addCIDGroupMembers"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -96,11 +96,11 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def deleteCIDGroupMembers(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def deleteCIDGroupMembers(self: object, body: dict) -> dict:
         """ Delete a set of Prevention Policies by specifying their IDs. """
         # [DELETE] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/deleteCIDGroupMembers
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "deleteCIDGroupMembers"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -113,13 +113,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def getCIDGroupById(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def getCIDGroupById(self: object, parameters: dict = None, **kwargs) -> dict:
         """Get CID Group(s) by ID(s)."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/getCIDGroupById
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "getCIDGroupById"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -129,11 +129,11 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def createCIDGroups(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def createCIDGroups(self: object, body: dict) -> dict:
         """Create new CID Group(s). Maximum 500 CID Group(s) allowed."""
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/createCIDGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "createCIDGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -146,13 +146,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def deleteCIDGroups(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def deleteCIDGroups(self: object, parameters: dict = None, **kwargs) -> dict:
         """Delete CID Group(s) by ID(s)."""
         # [DELETE] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/deleteCIDGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "deleteCIDGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="DELETE",
                                    endpoint=target_url,
@@ -162,13 +162,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def updateCIDGroups(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def updateCIDGroups(self: object, body: dict) -> dict:
         """Update existing CID Group(s). CID Group ID is expected for each CID
            Group definition provided in request body. CID Group member(s) remain unaffected.
         """
         # [PATCH] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/updateCIDGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "updateCIDGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -181,13 +181,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def getRolesByID(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def getRolesByID(self: object, parameters: dict = None, **kwargs) -> dict:
         """Get MSSP Role assignment(s). MSSP Role assignment is of the format <user_group_id>:<cid_group_id>."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/getRolesByID
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "getRolesByID"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -197,14 +197,14 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def addRole(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def addRole(self: object, body: dict) -> dict:
         """Assign new MSSP Role(s) between User Group and CID Group.
            It does not revoke existing role(s) between User Group and CID Group.
            User Group ID and CID Group ID have to be specified in request.
         """
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/addRole
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "addRole"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -216,7 +216,7 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def deleteRoles(self: object, *args, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def deleteRoles(self: object, *args, **kwargs) -> dict:
         """Delete MSSP Role assignment(s) between User Group and CID Group.
            User Group ID and CID Group ID have to be specified in request.
            Only specified roles are removed if specified in request payload,
@@ -229,15 +229,15 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
 
         return returned
 
-    def deletedRoles(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def deletedRoles(self: object, body: dict) -> dict:
         """Delete MSSP Role assignment(s) between User Group and CID Group.
            User Group ID and CID Group ID have to be specified in request.
            Only specified roles are removed if specified in request payload,
            else association between User Group and CID Group is dissolved completely (if no roles specified).
         """
         # [DELETE] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/deletedRoles
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "deletedRoles"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -250,13 +250,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def getUserGroupMembersByID(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103
+    def getUserGroupMembersByID(self: object, parameters: dict = None, **kwargs) -> dict:
         """Get User Group members by User Group ID(s)."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/getUserGroupMembersByID
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "getUserGroupMembersByID"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -266,11 +266,11 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def addUserGroupMembers(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def addUserGroupMembers(self: object, body: dict) -> dict:
         """Add new User Group member. Maximum 500 members allowed per User Group."""
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/addUserGroupMembers
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "addUserGroupMembers"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -282,11 +282,11 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def deleteUserGroupMembers(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def deleteUserGroupMembers(self: object, body: dict) -> dict:
         """Delete User Group members entry."""
         # [DELETE] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/deleteUserGroupMembers
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "deleteUserGroupMembers"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -299,13 +299,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def getUserGroupsByID(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def getUserGroupsByID(self: object, parameters: dict = None, **kwargs) -> dict:
         """Get User Groups by ID(s)."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/getUserGroupsByID
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "getUserGroupsByID"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -315,11 +315,11 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def createUserGroup(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def createUserGroup(self: object, body: dict) -> dict:
         """Create new User Group(s). Maximum 500 User Group(s) allowed per customer."""
         # [POST] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/createUserGroup
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "createUserGroup"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -332,13 +332,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def deleteUserGroups(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def deleteUserGroups(self: object, parameters: dict = None, **kwargs) -> dict:
         """Delete User Group(s) by ID(s)."""
         # [DELETE] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/deleteUserGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}".replace("?ids={}", "")
+        operation_id = "deleteUserGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}".replace("?ids={}", "")
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -348,13 +348,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
                                    )
         return returned
 
-    def updateUserGroups(self: object, body: dict) -> dict:  # pylint: disable=C0103  #Matching API
+    def updateUserGroups(self: object, body: dict) -> dict:
         """Update existing User Group(s). User Group ID is expected for each User Group
            definition provided in request body. User Group member(s) remain unaffected.
         """
         # [PATCH] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/updateUserGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "updateUserGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
         body_payload = body
         returned = service_request(caller=self,
@@ -367,13 +367,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def queryChildren(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def queryChildren(self: object, parameters: dict = None, **kwargs) -> dict:
         """Query for customers linked as children"""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/queryChildren
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "queryChildren"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -384,13 +384,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def queryCIDGroupMembers(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def queryCIDGroupMembers(self: object, parameters: dict = None, **kwargs) -> dict:
         """Query a CID Groups members by associated CID."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/queryCIDGroupMembers
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "queryCIDGroupMembers"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -401,13 +401,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def queryCIDGroups(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def queryCIDGroups(self: object, parameters: dict = None, **kwargs) -> dict:
         """Query a CID Groups."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/queryCIDGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "queryCIDGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -418,15 +418,15 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def queryRoles(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def queryRoles(self: object, parameters: dict = None, **kwargs) -> dict:
         """Query MSSP Role assignment. At least one of CID Group ID or
            User Group ID should also be provided. Role ID is optional.
         """
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/queryRoles
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "queryRoles"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -437,13 +437,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def queryUserGroupMembers(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def queryUserGroupMembers(self: object, parameters: dict = None, **kwargs) -> dict:
         """Query User Group member by User UUID."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/queryRoles
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "queryUserGroupMembers"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
@@ -454,13 +454,13 @@ class Flight_Control(ServiceClass):  # pylint: disable=C0103,R0904  # Matching A
         return returned
 
     @force_default(defaults=["parameters"], default_types=["dict"])
-    def queryUserGroups(self: object, parameters: dict = None, **kwargs) -> dict:  # pylint: disable=C0103  #Matching API
+    def queryUserGroups(self: object, parameters: dict = None, **kwargs) -> dict:
         """Query User Groups."""
         # [GET] https://assets.falcon.crowdstrike.com/support/api/swagger.html#/mssp/queryUserGroups
-        fname = sys._getframe().f_code.co_name  # pylint: disable=W0212  # Name lookup only
-        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if fname in ep[0]][0]}"
+        operation_id = "queryUserGroups"
+        target_url = f"{self.base_url}{[ep[2] for ep in ENDPOINTS if operation_id in ep[0]][0]}"
         header_payload = self.headers
-        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, fname)
+        parameter_payload = args_to_params(parameters, kwargs, ENDPOINTS, operation_id)
         returned = service_request(caller=self,
                                    method="GET",
                                    endpoint=target_url,
